@@ -14,15 +14,18 @@ import typing as t
 import warnings
 
 from libtmux import exc
-from libtmux.common import has_gte_version, has_lt_version, tmux_cmd
+from libtmux.common import tmux_cmd
 from libtmux.constants import (
     PANE_DIRECTION_FLAG_MAP,
     RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    OptionScope,
     PaneDirection,
     ResizeAdjustmentDirection,
 )
 from libtmux.formats import FORMAT_SEPARATOR
+from libtmux.hooks import HooksMixin
 from libtmux.neo import Obj, fetch_obj
+from libtmux.options import OptionsMixin
 
 if t.TYPE_CHECKING:
     import sys
@@ -43,7 +46,11 @@ logger = logging.getLogger(__name__)
 
 
 @dataclasses.dataclass()
-class Pane(Obj):
+class Pane(
+    Obj,
+    OptionsMixin,
+    HooksMixin,
+):
     """:term:`tmux(1)` :term:`Pane` [pane_manual]_.
 
     ``Pane`` instances can send commands directly to a pane, or traverse
@@ -90,6 +97,8 @@ class Pane(Obj):
        Accessed April 1st, 2018.
     """
 
+    default_option_scope: OptionScope | None = OptionScope.Pane
+    default_hook_scope: OptionScope | None = OptionScope.Pane
     server: Server
 
     def __enter__(self) -> Self:
@@ -275,20 +284,21 @@ class Pane(Obj):
         elif height or width:
             # Manual resizing
             if height:
-                if isinstance(height, str):
-                    if height.endswith("%") and not has_gte_version("3.1"):
-                        raise exc.VersionTooLow
-                    if not height.isdigit() and not height.endswith("%"):
-                        raise exc.RequiresDigitOrPercentage
+                if (
+                    isinstance(height, str)
+                    and not height.isdigit()
+                    and not height.endswith("%")
+                ):
+                    raise exc.RequiresDigitOrPercentage
                 tmux_args += (f"-y{height}",)
 
             if width:
-                if isinstance(width, str):
-                    if width.endswith("%") and not has_gte_version("3.1"):
-                        raise exc.VersionTooLow
-                    if not width.isdigit() and not width.endswith("%"):
-                        raise exc.RequiresDigitOrPercentage
-
+                if (
+                    isinstance(width, str)
+                    and not width.isdigit()
+                    and not width.endswith("%")
+                ):
+                    raise exc.RequiresDigitOrPercentage
                 tmux_args += (f"-x{width}",)
         elif zoom:
             # Zoom / Unzoom
@@ -585,7 +595,7 @@ class Pane(Obj):
         size: int, optional
             Cell/row or percentage to occupy with respect to current window.
         environment: dict, optional
-            Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
+            Environmental variables for new pane. Passthrough to ``-e``.
 
         Examples
         --------
@@ -650,16 +660,7 @@ class Pane(Obj):
             tmux_args += tuple(PANE_DIRECTION_FLAG_MAP[PaneDirection.Below])
 
         if size is not None:
-            if has_lt_version("3.1"):
-                if isinstance(size, str) and size.endswith("%"):
-                    tmux_args += (f"-p{str(size).rstrip('%')}",)
-                else:
-                    warnings.warn(
-                        'Ignored size. Use percent in tmux < 3.1, e.g. "size=50%"',
-                        stacklevel=2,
-                    )
-            else:
-                tmux_args += (f"-l{size}",)
+            tmux_args += (f"-l{size}",)
 
         if full_window_split:
             tmux_args += ("-f",)
@@ -670,7 +671,6 @@ class Pane(Obj):
         tmux_args += ("-P", "-F{}".format("".join(tmux_formats)))  # output
 
         if start_directory:
-            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
             start_path = pathlib.Path(start_directory).expanduser()
             tmux_args += (f"-c{start_path}",)
 
@@ -678,20 +678,14 @@ class Pane(Obj):
             tmux_args += ("-d",)
 
         if environment:
-            if has_gte_version("3.0"):
-                for k, v in environment.items():
-                    tmux_args += (f"-e{k}={v}",)
-            else:
-                logger.warning(
-                    "Environment flag ignored, tmux 3.0 or newer required.",
-                )
+            for k, v in environment.items():
+                tmux_args += (f"-e{k}={v}",)
 
         if shell:
             tmux_args += (shell,)
 
         pane_cmd = self.cmd("split-window", *tmux_args, target=target)
 
-        # tmux < 1.7. This is added in 1.7.
         if pane_cmd.stderr:
             if "pane too small" in pane_cmd.stderr:
                 raise exc.LibTmuxException(pane_cmd.stderr)
@@ -893,7 +887,7 @@ class Pane(Obj):
         percent: int, optional
             percentage to occupy with respect to current pane
         environment: dict, optional
-            Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
+            Environmental variables for new pane. Passthrough to ``-e``.
 
         Notes
         -----
